@@ -19,7 +19,7 @@ import os
 import json
 import logging
 
-from pymatgen.util.io_utils import zopen
+from monty.io import zopen
 from pymatgen.serializers.json_coders import PMGJSONEncoder, PMGJSONDecoder
 
 from multiprocessing import Manager, Pool
