@@ -47,8 +47,8 @@ from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Structure
 from pymatgen.symmetry.finder import SymmetryFinder
 from pymatgen.core.periodic_table import DummySpecie
-from pymatgen.util.io_utils import which
-from pymatgen.util.decorators import requires
+from monty.os.path import which
+from monty.dev import requires
 
 logger = logging.getLogger(__name__)
 
@@ -62,6 +62,24 @@ class EnumlibAdaptor(object):
     """
     An adaptor for enumlib.
 
+    Args:
+        structure: An input structure.
+        min_cell_size (int): The minimum cell size wanted. Defaults to 1.
+        max_cell_size (int): The maximum cell size wanted. Defaults to 1.
+        symm_prec (float): Symmetry precision. Defaults to 0.1.
+        enum_precision_parameter (float): Finite precision parameter for
+            enumlib. Default of 0.001 is usually ok, but you might need to
+            tweak it for certain cells.
+        refine_structure (bool): If you are starting from a structure that
+            has been relaxed via some electronic structure code,
+            it is usually much better to start with symmetry determination
+            and then obtain a refined structure. The refined structure have
+            cell parameters and atomic positions shifted to the expected
+            symmetry positions, which makes it much less sensitive precision
+            issues in enumlib. If you are already starting from an
+            experimental cif, refinement should have already been done and
+            it is not necessary. Defaults to False.
+
     .. attribute:: structures
 
         List of all enumerated structures.
@@ -71,30 +89,6 @@ class EnumlibAdaptor(object):
     def __init__(self, structure, min_cell_size=1, max_cell_size=1,
                  symm_prec=0.1, enum_precision_parameter=0.001,
                  refine_structure=False):
-        """
-        Args:
-            structure:
-                An input structure.
-            min_cell_size:
-                The minimum cell size wanted. Must be an int. Defaults to 1.
-            max_cell_size:
-                The maximum cell size wanted. Must be an int. Defaults to 1.
-            symm_prec:
-                Symmetry precision. Defaults to 0.1.
-            enum_precision_parameter:
-                Finite precision parameter for enumlib. Default of 0.001 is
-                usually ok, but you might need to tweak it for certain cells.
-            refine_structure:
-                If you are starting from a structure that has been relaxed via
-                some electronic structure code, it is usually much better to
-                start with symmetry determination and then obtain a refined
-                structure. The refined structure have cell parameters and
-                atomic positions shifted to the expected symmetry positions,
-                which makes it much less sensitive precision issues in enumlib.
-                If you are already starting from an experimental cif, refinment
-                should have already been done and it is not necessary. Defaults
-                to False.
-        """
         if refine_structure:
             finder = SymmetryFinder(structure, symm_prec)
             self.structure = finder.get_refined_structure()
