@@ -18,7 +18,8 @@ import re
 import json
 
 from pymatgen.core.units import Mass, Length, unitized
-from pymatgen.util.decorators import singleton, cached_class
+from monty.design_patterns import singleton, cached_class
+from monty.dev import deprecated
 from pymatgen.util.string_utils import formula_double_format
 from pymatgen.serializers.json_coders import MSONable
 from functools import total_ordering
@@ -42,8 +43,7 @@ def symbol_from_Z(z):
     Return the symbol of the element from the atomic number.
 
     Args:
-        z:
-            Atomic number or slice object
+        z (int): Atomic number or slice object
     """
     return _z2symbol[z]
 
@@ -58,6 +58,9 @@ class Element(object):
     attributes, missing data (i.e., data for which is not available) is
     represented by a None unless otherwise stated.
 
+    Args:
+        symbol (str): Element symbol, e.g., "H", "Fe"
+
     .. attribute:: Z
 
         Atomic number
@@ -274,13 +277,6 @@ class Element(object):
     """
 
     def __init__(self, symbol):
-        """
-        Create immutable element from a symbol.
-
-        Args:
-            symbol:
-                Element symbol, e.g., "H", "Fe"
-        """
         self._data = _pt_data[symbol]
 
         #Store key variables for quick access
@@ -449,8 +445,7 @@ class Element(object):
         Get an element from an atomic number.
 
         Args:
-            z:
-                Atomic number
+            z (int): Atomic number
 
         Returns:
             Element with atomic number z.
@@ -480,8 +475,7 @@ class Element(object):
         Returns true if symbol is a valid element symbol.
 
         Args:
-            symbol:
-                Element symbol
+            symbol (str): Element symbol
 
         Returns:
             True if symbol is a valid element (e.g., "H"). False otherwise
@@ -665,6 +659,13 @@ class Specie(MSONable):
     calculated to have a magmom of +4.5. Calculated properties should be
     assigned to Site objects, and not Specie.
 
+    Args:
+        symbol (str): Element symbol, e.g., Fe
+        oxidation_state (float): Oxidation state of element, e.g., 2 or -2
+        properties: Properties associated with the Specie, e.g.,
+            {"spin": 5}. Defaults to None. Properties must be one of the
+            Specie supported_properties.
+
     .. attribute:: oxi_state
 
         Oxidation state associated with Specie
@@ -681,17 +682,6 @@ class Specie(MSONable):
     supported_properties = ("spin",)
 
     def __init__(self, symbol, oxidation_state, properties=None):
-        """
-        Args:
-            symbol:
-                Element symbol, e.g., Fe
-            oxidation_state:
-                Oxidation state of element, e.g., 2 or -2
-            properties:
-                Properties associated with the Specie, e.g.,
-                {"spin":5}. Defaults to None. Properties must be one of the
-                Specie supported_properties.
-        """
         self._el = Element(symbol)
         self._oxi_state = oxidation_state
         self._properties = properties if properties else {}
@@ -774,9 +764,8 @@ class Specie(MSONable):
         Returns a Specie from a string representation.
 
         Args:
-            species_string:
-                A typical string representation of a species, e.g., "Mn2+",
-                "Fe3+", "O2-".
+            species_string (str): A typical string representation of a
+                species, e.g., "Mn2+", "Fe3+", "O2-".
 
         Returns:
             A Specie object.
@@ -808,10 +797,8 @@ class Specie(MSONable):
         configuration. Only works for transition metal species.
 
         Args:
-            coordination:
-                Only oct and tet are supported at the moment.
-            spin_config:
-                Supported keywords are "high" or "low".
+            coordination (str): Only oct and tet are supported at the moment.
+            spin_config (str): Supported keywords are "high" or "low".
 
         Returns:
             Crystal field spin in Bohr magneton.
@@ -881,6 +868,16 @@ class DummySpecie(MSONable):
     example, representation of vacancies (charged or otherwise), or special
     sites, etc.
 
+    Args:
+        symbol (str): An assigned symbol for the dummy specie. Strict
+            rules are applied to the choice of the symbol. The dummy
+            symbol cannot have any part of first two letters that will
+            constitute an Element symbol. Otherwise, a composition may
+            be parsed wrongly. E.g., "X" is fine, but "Vac" is not
+            because Vac contains V, a valid Element.
+        oxidation_state (float): Oxidation state for dummy specie.
+            Defaults to zero.
+
     .. attribute:: symbol
 
         Symbol for the DummySpecie.
@@ -899,18 +896,6 @@ class DummySpecie(MSONable):
     """
 
     def __init__(self, symbol="X", oxidation_state=0, properties=None):
-        """
-        Args:
-            symbol:
-                An assigned symbol for the dummy specie. Strict rules are
-                applied to the choice of the symbol. The dummy symbol cannot
-                have any part of first two letters that will constitute an
-                Element symbol. Otherwise, a composition may be parsed wrongly.
-                E.g., "X" is fine, but "Vac" is not because Vac contains V, a
-                valid Element.
-            oxidation_state:
-                Oxidation state for dummy specie. Defaults to zero.
-        """
         for i in range(1, min(2, len(symbol)) + 1):
             if Element.is_valid_symbol(symbol[:i]):
                 raise ValueError("{} contains {}, which is a valid element "
@@ -998,8 +983,8 @@ class DummySpecie(MSONable):
         Returns a Dummy from a string representation.
 
         Args:
-            species_string:
-                A string representation of a dummy species, e.g., "X2+", "X3+"
+            species_string (str): A string representation of a dummy
+                species, e.g., "X2+", "X3+".
 
         Returns:
             A DummySpecie object.
@@ -1079,7 +1064,7 @@ class PeriodicTable(object):
     @property
     def all_elements(self):
         """
-        Returns the list of all known elements as Element objects.
+        List of all known elements as Element objects.
         """
         return self._all_elements.values()
 
@@ -1089,12 +1074,10 @@ class PeriodicTable(object):
         filter_function.
 
         Args:
-            filter_function:
-                A filtering function taking an Element as input and returning
-                a boolean. For example, setting
-                filter_function = lambda el: el.X > 2 will print
-                a periodic table containing only elements with
-                electronegativity > 2.
+            filter_function: A filtering function taking an Element as input
+                and returning a boolean. For example, setting
+                filter_function = lambda el: el.X > 2 will print a periodic
+                table containing only elements with electronegativity > 2.
         """
         for row in range(1, 10):
             rowstr = []
@@ -1107,7 +1090,7 @@ class PeriodicTable(object):
             print(" ".join(rowstr))
 
 
-def smart_element_or_specie(obj):
+def get_el_sp(obj):
     """
     Utility method to get an Element or Specie from an input obj.
     If obj is in itself an element or a specie, it is returned automatically.
@@ -1118,10 +1101,9 @@ def smart_element_or_specie(obj):
     DummyElement parsing will be attempted.
 
     Args:
-        obj:
-            An arbitrary object.  Supported objects are actual Element/Specie
-            objects, integers (representing atomic numbers) or strings (element
-            symbols or species strings).
+        obj (Element/Specie/str/int): An arbitrary object.  Supported objects
+            are actual Element/Specie objects, integers (representing atomic
+            numbers) or strings (element symbols or species strings).
 
     Returns:
         Specie or Element, with a bias for the maximum number of properties
@@ -1155,3 +1137,14 @@ def smart_element_or_specie(obj):
             except:
                 raise ValueError("Can't parse Element or String from " +
                                  str(obj))
+
+
+
+@deprecated(replacement=get_el_sp)
+def smart_element_or_specie(obj):
+    """
+    .. deprecated:: v2.8.11
+
+        Use get_el_sp instead.
+    """
+    return get_el_sp(obj)
