@@ -19,7 +19,7 @@ from pymatgen.electronic_structure.core import Spin, Orbital
 from pymatgen.core.structure import Structure
 from pymatgen.util.coord_utils import get_linear_interpolated_value
 from pymatgen.serializers.json_coders import MSONable
-from pymatgen.util.decorators import requires
+from monty.dev import requires
 
 try:
     import scipy
@@ -32,6 +32,12 @@ class Dos(MSONable):
     Basic DOS object. All other DOS objects are extended versions of this
     object.
 
+    Args:
+        efermi: Fermi level energy
+        energies: A sequences of energies
+        densities ({Spin: np.array}): representing the density of states
+            for each Spin.
+
     .. attribute: energies
 
         The sequence of energies
@@ -46,16 +52,6 @@ class Dos(MSONable):
     """
 
     def __init__(self, efermi, energies, densities):
-        """
-        Args:
-            efermi:
-                Fermi level energy
-            energies:
-                A sequences of energies
-            densities:
-                A dict of {Spin: np.array} representing the density of states
-                for each Spin.
-        """
         self.efermi = efermi
         self.energies = np.array(energies)
         self.densities = {k: np.array(d) for k, d in densities.items()}
@@ -65,8 +61,7 @@ class Dos(MSONable):
         Returns the density of states for a particular spin.
 
         Args:
-            spin:
-                Spin
+            spin: Spin
 
         Returns:
             Returns the density of states for a particular spin. If Spin is
@@ -92,8 +87,7 @@ class Dos(MSONable):
         level.
 
         Args:
-            sigma:
-                Std dev of Gaussian smearing function.
+            sigma: Std dev of Gaussian smearing function.
 
         Returns:
             Dict of Gaussian-smeared densities.
@@ -113,8 +107,7 @@ class Dos(MSONable):
         Otherwise, a ValueError is thrown.
 
         Args:
-            other:
-                Another DOS object.
+            other: Another DOS object.
 
         Returns:
             Sum of the two DOSs.
@@ -130,8 +123,7 @@ class Dos(MSONable):
         Returns interpolated density for a particular energy.
 
         Args:
-            energy:
-                Energy to return the density for.
+            energy: Energy to return the density for.
         """
         f = {}
         for spin in self.densities.keys():
@@ -145,16 +137,12 @@ class Dos(MSONable):
         Expects a DOS object and finds the gap
 
         Args:
-            tol:
-                tolerance in occupations for determining the gap
-            abs_tol:
-                Set to True for an absolute tolerance and False for a relative
-                one.
-            spin:
-                Possible values are:
-                    None - finds the ap in the summed densities
-                    Up - finds the gap in the up spin channel
-                    Down - finds the gap in teh down spin channel
+            tol: tolerance in occupations for determining the gap
+            abs_tol: Set to True for an absolute tolerance and False for a
+                relative one.
+            spin: Possible values are None - finds the gap in the summed
+                densities, Up - finds the gap in the up spin channel,
+                Down - finds the gap in the down spin channel.
 
         Returns:
             (gap, cbm, vbm):
@@ -190,15 +178,11 @@ class Dos(MSONable):
         Expects a DOS object and finds the cbm and vbm.
 
         Args:
-            tol:
-                tolerance in occupations for determining the gap
-            abs_tol:
-                an absolute tolerance (True) and a relative one (False)
-            spin:
-                Possible values are:
-                    None - finds the gap in the summed densities
-                    Up - finds the gap in the up spin channel
-                    Down - finds the gap in teh down spin channel
+            tol: tolerance in occupations for determining the gap
+            abs_tol: An absolute tolerance (True) and a relative one (False)
+            spin: Possible values are None - finds the gap in the summed
+                densities, Up - finds the gap in the up spin channel,
+                Down - finds the gap in the down spin channel.
 
         Returns:
             (cbm, vbm): float in eV corresponding to the gap
@@ -230,15 +214,11 @@ class Dos(MSONable):
         Expects a DOS object and finds the gap.
 
         Args:
-            tol:
-                tolerance in occupations for determining the gap
-            abs_tol:
-                an absolute tolerance (True) and a relative one (False)
-            spin:
-                Possible values are:
-                    None - finds the gap in the summed densities
-                    Up - finds the gap in the up spin channel
-                    Down - finds the gap in teh down spin channel
+            tol: tolerance in occupations for determining the gap
+            abs_tol: An absolute tolerance (True) and a relative one (False)
+            spin: Possible values are None - finds the gap in the summed
+                densities, Up - finds the gap in the up spin channel,
+                Down - finds the gap in the down spin channel.
 
         Returns:
             gap in eV
@@ -293,6 +273,12 @@ class CompleteDos(Dos):
     a vasprun.xml file. You are unlikely to try to generate this object
     manually.
 
+    Args:
+        structure: Structure associated with this particular DOS.
+        total_dos: total Dos for structure
+        pdoss: The pdoss are supplied as an {Site:{Orbital:{
+            Spin:Densities}}}
+
     .. attribute:: structure
 
         Structure associated with the CompleteDos.
@@ -302,16 +288,6 @@ class CompleteDos(Dos):
         Dict of partial densities of the form {Site:{Orbital:{Spin:Densities}}}
     """
     def __init__(self, structure, total_dos, pdoss):
-        """
-            Args:
-                structure:
-                    Structure associated with this particular DOS.
-                total_dos:
-                    total Dos for structure
-                pdoss:
-                    The pdoss are supplied as an {Site:{Orbital:{
-                    Spin:Densities}}}
-            """
         Dos.__init__(self, total_dos.efermi, energies=total_dos.energies,
                      densities={k: np.array(d)
                                 for k, d in total_dos.densities.items()})
@@ -323,10 +299,8 @@ class CompleteDos(Dos):
         Get the Dos for a particular orbital of a particular site.
 
         Args:
-            site:
-                Site in Structure associated with CompleteDos.
-            orbital:
-                Orbital in the site.
+            site: Site in Structure associated with CompleteDos.
+            orbital: Orbital in the site.
 
         Returns:
             Dos containing densities for orbital of site.
@@ -338,8 +312,7 @@ class CompleteDos(Dos):
         Get the total Dos for a site (all orbitals).
 
         Args:
-            site:
-                Site in Structure associated with CompleteDos.
+            site: Site in Structure associated with CompleteDos.
 
         Returns:
             Dos containing summed orbital densities for site.
@@ -352,8 +325,7 @@ class CompleteDos(Dos):
         Get the t2g, eg projected DOS for a particular site.
 
         Args:
-            site:
-                Site in Structure associated with CompleteDos.
+            site: Site in Structure associated with CompleteDos.
 
         Returns:
             A dict {"e_g": Dos, "t2g": Dos} containing summed e_g and t2g DOS
@@ -464,10 +436,8 @@ def add_densities(density1, density2):
     Method to sum two densities.
 
     Args:
-        density1:
-            First density.
-        density2:
-            Second density.
+        density1: First density.
+        density2: Second density.
 
     Returns:
         Dict of {spin: density}.
