@@ -6,9 +6,9 @@ from __future__ import division, print_function
 
 import collections
 import numpy as np
-import yaml
 
 from StringIO import StringIO
+from pymatgen.io.abinitio import myaml
 from pymatgen.util.string_utils import pprint_table
 
 
@@ -492,7 +492,7 @@ def yaml_read_kpoints(filename, doc_tag="!Kpoints"):
     """Read the K-points from file."""
     with YamlTokenizer(filename) as r:
         doc = r.next_doc_with_tag(doc_tag)
-        d = yaml.load(doc.text_notag)
+        d = myaml.load(doc.text_notag)
 
         return np.array(d["reduced_coordinates_of_qpoints"])
 
@@ -501,7 +501,7 @@ def yaml_read_irred_perts(filename, doc_tag="!IrredPerts"):
     """Read the lisr of irreducible perturbations from file."""
     with YamlTokenizer(filename) as r:
         doc = r.next_doc_with_tag(doc_tag)
-        d = yaml.load(doc.text_notag)
+        d = myaml.load(doc.text_notag)
 
         return d["irred_perts"]
 
