@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 Low-level objects providing an abstraction for the objects involved in the
 calculation.
@@ -13,7 +11,7 @@ import numpy as np
 import pymatgen.core.units as units
 
 from pprint import pformat
-from pymatgen.util.decorators import singleton
+from monty.design_patterns import singleton
 from pymatgen.util.string_utils import is_string
 from pymatgen.core.design_patterns import Enum, AttrDict
 from pymatgen.core.units import ArrayWithUnit
@@ -128,7 +126,7 @@ class Smearing(AbivarAble, MSONable):
         return s
 
     def __eq__(self, other):
-        return (self.occopt == other.occopt and 
+        return (self.occopt == other.occopt and
                 np.allclose(self.tsmear, other.tsmear))
 
     def __ne__(self, other):
@@ -583,7 +581,7 @@ class KSampling(AbivarAble):
             False if time-reversal symmetry should not be used to reduced the number of independent k-points.
 
         Returns:
-            KSampling object
+            `KSampling` object.
         """
         return cls(kpts              = [kpts],
                    use_symmetries    = use_symmetries,
@@ -592,7 +590,7 @@ class KSampling(AbivarAble):
                    )
 
     @classmethod
-    def monkhorst(cls, ngkpt, shiftk=(0.5, 0.5, 0.5), chksymbreak=None, use_symmetries=True, 
+    def monkhorst(cls, ngkpt, shiftk=(0.5, 0.5, 0.5), chksymbreak=None, use_symmetries=True,
                   use_time_reversal=True, comment=None):
         """
         Convenient static constructor for a Monkhorst-Pack mesh.
@@ -608,7 +606,7 @@ class KSampling(AbivarAble):
                 Use time-reversal symmetry to reduce the number of k-points.
 
         Returns:
-            KSampling object
+            `KSampling` object.
         """
         return cls(kpts              = [ngkpt],
                    kpt_shifts        = shiftk,
@@ -972,28 +970,57 @@ class PPModel(AbivarAble, MSONable):
 
 
 class HilbertTransform(AbivarAble):
-    "Parameters for the Hilbert-transform method (RPA, Screening code)"
-
-    def __init__(self, nomegasf, spmeth=1):
+    """
+    Parameters for the Hilbert-transform method (Screening code)
+    i.e. the parameters defining the frequency mesh used for the spectral function
+    and the frequency mesh used for the polarizability
+    """
+    def __init__(self, nomegasf, domegasf=None, spmeth=1, nfreqre=None, freqremax=None, nfreqim=None, freqremin=None):
         """
         Args:
             nomegasf:
                 Number of points for sampling the spectral function along the real axis.
-            spmeth
+            domegasf:
+                Step in Ha for the linear mesh used for the spectral function.
+            spmeth:
                 Algorith for the representation of the delta function.
+            nfreqre:
+                Number of points along the real axis (linear mesh).
+            freqremax:
+                Maximum frequency for W along the real axis (in hartree).
+            nfreqim:
+                Number of point along the imaginary axis (Gauss-Legendre mesh).
+            freqremin:
+                Minimum frequency for W along the real axis (in hartree).
         """
-        self.spmeth   = spmeth
+        # Spectral function
         self.nomegasf = nomegasf
+        self.domegasg = domegasf
+        self.spmeth   = spmeth
+
+        # Mesh for the contour-deformation method used for the integration of the self-energy
+        self.nfreqre = nfreqre
+        self.freqremax = freqremax
+        self.freqremin = freqremin
+        self.nfreqim = nfreqim
 
     def to_abivars(self):
-        return {"spmeth"  : self.spmeth,
-                "nomegasf": self.nomegasf,}
-
+        """Returns a dictionary with the abinit variables"""
+        return {
+                # Spectral function
+                "nomegasf": self.nomegasf,
+                "domegasf": self.domegasf,
+                "spmeth"  : self.spmeth,
+                 # Frequency mesh for the polarizability
+                "nfreqre"  : self.nfreqre,
+                "freqremax": self.freqremax,
+                "nfreqim"  : self.nfreqim,
+                "freqremin": self.freqremin,
+                }
 
 
 class ModelDielectricFunction(AbivarAble):
-    "Model dielectric function used for BSE calculation"
-
+    """Model dielectric function used for BSE calculation"""
     def __init__(self, mdf_epsinf):
         self.mdf_epsinf = mdf_epsinf
 
@@ -1005,43 +1032,9 @@ class ModelDielectricFunction(AbivarAble):
 ##########################################################################################
 
 
-class CDFrequencyMesh(AbivarAble):
-    "Mesh for the contour-deformation method used for the integration of the self-energy"
-    #
-    #    def __init__(self, r_slice, nfreqim=10, freqim_alpha=5, units="Ha"):
-             #np.arange(start, s.stop, step))
-    #        self.r_slice = r_slice
-    #        self.units = units
-
-    #    #def from_slice
-    #    #def from_linspace
-    #    #FrequencyMesh(real_slice=slice(0,15,1), units="Ha")
-
-    #    @property
-    #    def num_real_points(self)
-    #        """Number of points along the real axis."""
-    #    @property
-    #    def num_imag_points(self)
-    #        """Number of points along the imaginary axis."""
-    #    @property
-    #    def r_step(self)
-    #        """Step used to sample the real axis (Ha units)"""
-
-    def to_abivars(self):
-        "Returns a dictionary with the abinit variables"
-        abivars = {
-            "freqremax"   : self.freqremax,
-            "freqremin"   : self.freqremin,
-            "nfreqre"     : self.nfreqre,
-            "nfreqim"     : self.nfreqim,
-            "freqim_alpha": self.freqim_alpha
-        }
-        return abivars
-
-
 class Screening(AbivarAble):
     """
-    This object defines the parameters used for the 
+    This object defines the parameters used for the
     computation of the screening function.
     """
     # Approximations used for W
@@ -1057,7 +1050,7 @@ class Screening(AbivarAble):
     }
 
     def __init__(self, ecuteps, nband, w_type="RPA", sc_mode="one_shot",
-                 freq_mesh=None, hilbert_transform=None, ecutwfn=None, inclvkb=2):
+                 hilbert=None, ecutwfn=None, inclvkb=2):
         """
         Args:
             ecuteps:
@@ -1068,9 +1061,7 @@ class Screening(AbivarAble):
                 Screening type
             sc_mode:
                 Self-consistency mode.
-            freq_mesh=None, 
-                Instance of `CDFrequencyMesh` defining the parameters for the contour deformation technique.
-            hilbert_transform:
+            hilbert:
                 Instance of `HilbertTransform` defining the paramentes for the Hilber transform method.
             ecutwfn:
                 Cutoff energy for the wavefunctions (Default: ecutwfn == ecut).
@@ -1091,21 +1082,9 @@ class Screening(AbivarAble):
         self.ecutwfn = ecutwfn
         self.inclvkb = inclvkb
 
-        #if [obj is not None for obj in [ppmodel, freq_mesh]].count(True) != 1:
-        #    raise ValueError("Either ppmodel or freq_mesh can be specified")
-
-        #if ppmodel is not None:
-        #    self.ppmodel = PPModel.asppmodel(ppmodel)
-
-        if freq_mesh is not None:
-            raise NotImplementedError("")
-            self.wmesh = WMesh.aswmesh(wmesh)
-
-        if hilbert_transform is not None:
-            if not self.has_wmesh:
-                raise ValueError("Hilber transform method requires the "
-                                 "specification of the frequency mesh")
-            self.hilbert_transform = hilbert_transform
+        if hilbert is not None:
+            raise NotImplementedError("Hilber transform not coded yet")
+            self.hilbert = hilbert
 
         # Default values
         # TODO Change abinit defaults
@@ -1114,12 +1093,8 @@ class Screening(AbivarAble):
         self.symchi = 1
 
     @property
-    def has_wmesh(self):
-        return hasattr(self, "wmesh")
-
-    @property
-    def has_hilbert_transform(self):
-        return hasattr(self, "hilbert_transform")
+    def use_hilbert(self):
+        return hasattr(self, "hilbert")
 
     #@property
     #def gwcalctyp(self):
@@ -1141,24 +1116,16 @@ class Screening(AbivarAble):
             #"fftgw"    : self.fftgw,
         }
 
-        # Variables for PPmodel.
-        #if self.has_ppmodel:
-        #    abivars.update(self.ppmodel.to_abivars())
-
         # Variables for the Hilber transform.
-        if self.has_hilbert_transform:
-            abivars.update(self.hilbert_transform.to_abivars())
-
-        # Frequency mesh.
-        if self.has_wmesh:
-            abivars.update(self.wmesh.to_abivars())
+        if self.use_hilbert:
+            abivars.update(self.hilbert.to_abivars())
 
         return abivars
 
 
 class SelfEnergy(AbivarAble):
     """
-    This object defines the parameters used for the 
+    This object defines the parameters used for the
     computation of the self-energy.
     """
     _SIGMA_TYPES = {
@@ -1177,7 +1144,7 @@ class SelfEnergy(AbivarAble):
     }
 
     def __init__(self, se_type, sc_mode, nband, ecutsigx, screening,
-                 ppmodel=None, ecuteps=None, ecutwfn=None):
+                 gw_qprange=1, ppmodel=None, ecuteps=None, ecutwfn=None):
         """
         Args:
             se_type:
@@ -1190,6 +1157,10 @@ class SelfEnergy(AbivarAble):
                 Cutoff energy for the exchange part of the self-energy (Ha units).
             screening:
                 `Screening` instance.
+            gw_qprange:
+                Option for the automatic selection of k-points and bands for GW corrections.
+                See Abinit docs for more detail. The default value makes the code computie the
+                QP energies for all the point in the IBZ and one band above and one band below the Fermi level.
             ppmodel:
                 `PPModel` instance with the parameters used for the plasmon-pole technique.
             ecuteps:
@@ -1208,13 +1179,14 @@ class SelfEnergy(AbivarAble):
         self.nband     = nband
         self.ecutsigx  = ecutsigx
         self.screening = screening
+        self.gw_qprange = gw_qprange
 
         if ppmodel is not None:
+            assert not screening.use_hilbert
             self.ppmodel = PPModel.asppmodel(ppmodel)
 
-        self.ecuteps  = ecuteps if ecuteps is not None else screening.ecuteps
-
-        self.ecutwfn  = ecutwfn
+        self.ecuteps = ecuteps if ecuteps is not None else screening.ecuteps
+        self.ecutwfn = ecutwfn
 
         #band_mode in ["gap", "full"]
 
@@ -1240,13 +1212,13 @@ class SelfEnergy(AbivarAble):
         #self.freq_int = freq_int
 
     @property
-    def has_ppmodel(self):
+    def use_ppmodel(self):
         """True if we are using the plasmon-pole approximation."""
         return hasattr(self, "ppmodel")
 
     @property
     def gwcalctyp(self):
-        "Returns the value of the gwcalctyp input variable"
+        """Returns the value of the gwcalctyp input variable."""
         dig0 = str(self._SIGMA_TYPES[self.type])
         dig1 = str(self._SC_MODES[self.sc_mode])
         return dig1.strip() + dig0.strip()
@@ -1259,22 +1231,23 @@ class SelfEnergy(AbivarAble):
     def to_abivars(self):
         "Returns a dictionary with the abinit variables"
 
-        abivars = {
-            "gwcalctyp": self.gwcalctyp,
-            "ecuteps"  : self.ecuteps,
-            "ecutsigx" : self.ecutsigx,
-            "symsigma" : self.symsigma,
+        abivars = dict(
+            gwcalctyp=self.gwcalctyp,
+            ecuteps=self.ecuteps,
+            ecutsigx=self.ecutsigx,
+            symsigma=self.symsigma,
+            gw_qprange=self.gw_qprange,
             #"ecutwfn"  : self.ecutwfn,
             #"kptgw"    : self.kptgw,
             #"nkptgw"   : self.nkptgw,
             #"bdgw"     : self.bdgw,
-        }
+        )
 
         # FIXME: problem with the spin
         #assert len(self.bdgw) == self.nkptgw
 
         # ppmodel variables
-        if self.has_ppmodel:
+        if self.use_ppmodel:
             abivars.update(self.ppmodel.to_abivars())
 
         return abivars
@@ -1288,7 +1261,7 @@ class ExcHamiltonian(AbivarAble):
         "coupling": 1,     # Calculation with coupling.
     }
 
-    # Algorithms used to compute the macroscopic dielectric function 
+    # Algorithms used to compute the macroscopic dielectric function
     # and/or the exciton wavefunctions.
     _ALGO2VAR = {
         "direct_diago": 1,
@@ -1303,54 +1276,64 @@ class ExcHamiltonian(AbivarAble):
         "model_df"
         ]
 
-    def __init__(self, bs_loband, nband, soenergy, coulomb_mode, ecuteps, bs_freq_mesh, mdf_epsinf=None, 
-                exc_type="TDA", algo="haydock", with_lf=True, zcut=None, **kwargs):
+    def __init__(self, bs_loband, nband, soenergy, coulomb_mode, ecuteps, spin_mode="polarized", mdf_epsinf=None,
+                exc_type="TDA", algo="haydock", with_lf=True, bs_freq_mesh=None, zcut=None, **kwargs):
         """
         Args:
-            bs_loband: 
-                Lowest band index used in the e-h  basis set.
-            nband: 
+            bs_loband:
+                Lowest band index used in the e-h  basis set. Can be scalar or array of shape (nsppol,)
+            nband:
                 Max band index used in the e-h  basis set.
-            soenergy: 
+            soenergy:
                 Scissors energy in Hartree.
-            coulomb_mode: 
+            coulomb_mode:
                 Treatment of the Coulomb term.
-            ecuteps: 
+            ecuteps:
                 Cutoff energy for W in Hartree.
-            bs_freq_mesh:
-                Frequency mesh for the macroscopic dielectric function (start, stop, step) in Ha.
-            mdf_epsinf: 
-                Macroscopic dielectric function :math:`\epsilon_\inf` used in 
+            mdf_epsinf:
+                Macroscopic dielectric function :math:`\epsilon_\inf` used in
                 the model dielectric function.
             exc_type:
                 Approximation used for the BSE Hamiltonian
             with_lf:
-                True if local field effects are includes <==> exchange term is included
+                True if local field effects are included <==> exchange term is included
+            bs_freq_mesh:
+                Frequency mesh for the macroscopic dielectric function (start, stop, step) in Ha.
             zcut:
                 Broadening parameter in Ha.
             **kwargs:
                 Extra keywords
         """
+        spin_mode = SpinMode.asspinmode(spin_mode)
+
+        # We want an array bs_loband(nsppol).
+        try:
+            bs_loband = np.reshape(bs_loband, (spin_mode.nsppol))
+        except ValueError:
+            bs_loband = np.array(spin_mode.nsppol * [int(bs_loband)])
+
         self.bs_loband = bs_loband
         self.nband  = nband
         self.soenergy = soenergy
         self.coulomb_mode = coulomb_mode
         assert coulomb_mode in self._COULOMB_MODES
         self.ecuteps = ecuteps
-        self.bs_freq_mesh = np.array(bs_freq_mesh)
+
         self.mdf_epsinf = mdf_epsinf
         self.exc_type = exc_type
         assert exc_type in self._EXC_TYPES
         self.algo = algo
         assert algo in self._ALGO2VAR
         self.with_lf = with_lf
-        self.zcut = zcut
 
-        # TODO
-        #self.chksymbreak = 0
+        # if bs_freq_mesh is not given, abinit will select its own mesh.
+        self.bs_freq_mesh = np.array(bs_freq_mesh) if bs_freq_mesh is not None else bs_freq_mesh
+        self.zcut = zcut
 
         # Extra options.
         self.kwargs = kwargs
+        if "chksymbreak" not in self.kwargs:
+            self.kwargs["chksymbreak"] = 0
 
     @property
     def inclvkb(self):
@@ -1372,31 +1355,22 @@ class ExcHamiltonian(AbivarAble):
         """True if we are performing the direct diagonalization of the BSE Hamiltonian."""
         return self.algo == "direct_diago"
 
-    @classmethod
-    def TDA_with_model_df(cls, bs_loband, nband, soenery, mdf_einf, soenergy, **kwargs):
-        """
-        Static constructor used for performing Tamm-Dancoff calculations 
-        with the model dielectric functions and the scissors operator.
-        """
-        raise NotImplementedError("")
-        return cls(bs_loband, nband, soenergy, "model_df", ecuteps, bs_freq_mesh, 
-                   mdf_epsinf=mdf_eing, exc_type="TDA", with_lf=True, **kwargs)
-
     def to_abivars(self):
-        "Returns a dictionary with the abinit variables"
+        """Returns a dictionary with the abinit variables."""
 
         abivars = dict(
+            bs_calctype=1,
             bs_loband=self.bs_loband,
+            nband=self.nband,
             soenergy=self.soenergy,
             ecuteps=self.ecuteps,
-            bs_freq_mesh=self.bs_freq_mesh,
-            #bs_algo = self._ALGO2VAR[self.algo],
+            #bs_algorithm = self._ALGO2VAR[self.algo],
             bs_coulomb_term=21,
-            bs_calctype=1,
-            inclvkb=self.inclvkb,
-            bs_exchange_term=1 if self.with_lf else 0,
-            zcut=self.zcut,
             mdf_epsinf=self.mdf_epsinf,
+            bs_exchange_term=1 if self.with_lf else 0,
+            inclvkb=self.inclvkb,
+            zcut=self.zcut,
+            bs_freq_mesh=self.bs_freq_mesh,
             )
 
         if self.use_haydock:
@@ -1409,234 +1383,138 @@ class ExcHamiltonian(AbivarAble):
 
         elif self.use_direct_diago:
             raise NotImplementedError("")
-            abivars.update(
-                foo=1,
-            )
 
         elif self.use_cg:
             raise NotImplementedError("")
-            abivars.update(
-                foo=1,
-            )
 
         else:
             raise ValueError("Unknown algorithm for EXC: %s" % self.algo)
 
+        # Add extra kwargs
         abivars.update(self.kwargs)
 
         return abivars
 
 
-
-class Perturbation(AbivarAble):
-    """
-    Base class for perturbations: a base perturbation is essentially defined 
-    by a q-point in reduced coordinates.
-
-    Subclasses should extend the base method `to_abivars` and provide the method `suggested_kptopt` 
-    that returns the value of kptopt that can be used to sample the Brillouin zone.
-    """
-    def __init__(self, qpt):
-        """
-        Args:
-            qpt:
-                reduced coordinates of the q-point associated to the perturbation.
-        """
-        self.qpt = np.reshape(qpt, (-1,3))
-        self.nqpt = len(self.qpt)
-
-    @property
-    def qpt_is_gamma(self):
-        """True if the q-point of the perturbation is Gamma."""
-        return np.all(np.abs(self.qpt) < 1.e-6)
-
-    @abc.abstractproperty
-    def suggested_kptopt(self):
-        """Returns the suggested value of kptopt to use for this perturbation."""
-        return 3
-
-    def to_abivars(self):
-        return dict(nqpt=1, qpt=self.qpt)
-
-
-class PhononPerturbation(Perturbation):
-    """
-    A phonon perturbation is specified by the q-point in reduced 
-    coordinates, the index of the displaced atom and the reduced direction.
-    along which the atom is moved.
-    """
-    def __init__(self, qpt, rfatpol, rfdir):
-        super(PhononPerturbation, self).__init__(qpt)
-        self.rfatpol = rfatpol
-        self.rfdir = np.reshape(rfdir, (3,))
-
-    @property
-    def suggested_kptopt(self):
-        if self.qpt_is_gamma:
-            # Automatic generation of k points, taking
-            # into account the time-reversal symmetry only.
-            return 2
-        else:
-            # Don't use symmetries
-            return 3
-
-    def to_abivars(self):
-        #Example::
-        #                                                                     
-        # Response-function calculation, with q=0
-        # rfphon  1        # Will consider phonon-type perturbation
-        # rfatpol 1 2      # All the atoms will be displaced
-        # rfdir   1 1 1    # Along all reduced coordinate axis
-        # nqpt    1        # One wavevector is to be considered
-        # qpt     0 0 0    # This wavevector is q=0 (Gamma)
-        # kptopt  2        # Automatic generation of k points (time-reversal symmetry only)
-        abivars = super(PhononPertubation, self).to_abivars()
-
-        abivars.extend(dict(
-            rfphon=1,             
-            rfatpol=self.rfatpol, 
-            rfdir=self.rfdir,
-        ))
-
-        return abivars
-
-
-class DDKPerturbation(Perturbation):
-    """
-    A DDK perturbation is specified by the q-point in reduced 
-    coordinates, and the direction in k-space.
-    """
-    def __init__(self, rfdir):
-        # Calculation at the Gamma point
-        super(DDKPertubation, self).__init__(qpt=[0.0, 0.0, 0.0])
-        self.rfdir = np.reshape(rfdir, (3,))
-
-    @property
-    def suggested_kptopt(self):
-        return 2
-
-    def to_abivars(self):
-        abivars = super(DDKPert, self).to_abivars()
-
-        abivars.extend(dict(
-            rfelfd=2,           # Activate the calculation of the d/dk perturbation
-            rfdir=self.rdfdir   # Direction of the perturbation
-        ))
-        return abivars
-
-
-#class ElectricPertubation(Perturbation):
-#    def __init__(self, rfdir):
-#        # Calculation at the Gamma point
-#        super(ElectricPertubation, self).__init__(qpt=[0.0, 0.0, 0.0])
-
-
-#class ElasticPertubation(Perturbation):
-#    def __init__(self, rfdir):
-#        # Calculation at the Gamma point
-#        super(ElasticPertubation, self).__init__(qpt=[0.0, 0.0, 0.0])
-
-
-#def irred_perturbations(input, qpoint):
+#class Perturbation(AbivarAble):
 #    """
-#    This function returns the list of irreducible perturbations at the given q-point.
-#    """
-#    # Call abinit to get the irred perturbations.
-#    #pert_info = get_pert_info()
+#    Base class for perturbations: a base perturbation is essentially defined
+#    by a q-point in reduced coordinates.
 #
-#    # Initialize the list of irreducible perturbations.
-#    perts = []
-#    return perts
-
-
-class IFC(AbivarAble):
-    """
-    This object defines the set of variables used for the
-    Fourier interpolation of the interatomic force constants.
-    """
-    def __init__(self, ddb_filename, ngqpt, q1shfts=(0.,0.,0.), ifcflag=1, brav=1):
-        """
-        For the complete description of the meaning of the variables see anaddb_help.html
-
-        Args:
-            ddb_filename:
-                Path to the DDB file.
-            ngqpt:
-                Monkhorst-Pack divisions.
-            q1shfts:
-                Monkhorst-Pack shifts.
-            ifcflag:
-                Interatomic force constant flag.
-            brav:
-                Bravais Lattice: 1-S.C., 2-F.C., 3-B.C., 4-Hex.
-        """
-        self.ddb_filename = os.path.abspath(ddb_filename)
-        if not os.path.exists(self.ddb_filename):
-            raise ValueError("%s: no such file" % self.ddb_filename)
-
-        self.ifcflag = ifcflag
-        self.brav = brav
-        self.ngqpt = ngqpt
-
-        self.q1shft = np.reshape(q1shft, (-1,3))
-        self.nqshft = len(self.q1shft)
-
-    def to_abivars(self):
-        d = dict(
-            ifcflag=self.ifcflag,
-            brav=self.brav,
-            ngqpt="%d %d %d" % tuple(q for q in self.ngqpt),
-            nqshft=self.nqshft,
-            )
-
-        lines = []
-        for shift in self.q1shfts:
-            lines.append("%f %f %f" % tuple(c for c in shift))
-        d["q1shfts"] = "\n".join(lines)
-
-        return d
-
-    def fourier_interpol(self, qpath=None, qmesh=None, symdynmat=1, asr=1, chneut=1, dipdip=1, 
-                         executable=None, verbose=0):
-        """
-        Fourier interpolation of the IFCs.
-
-        Args:
-            asr:
-                Acoustic Sum Rule. 1 to impose it asymetrically.
-            chneut:
-                Charge neutrality requirement for effective charges.
-            dipdip:
-                Dipole-dipole interaction treatment.
-            symdinmat:
-                TODO
-        """
-        # Build input for anaddb. Variables are stored in the dict d.
-        d = {
-            "symdynmat": symdynmat,
-            "asr"      : asr,
-            "chneut"   : chneut,
-            "dipdip"   : dipdip,
-        }
-
-        # Phonon band structure.
-        if qpath is not None:
-            qpath = np.reshape(qpath, (-1,3))
-            d.update({
-                "nqpath": len(qpath),
-                "qpath" : "\n".join("%f %f %f" % tuple(q) for q in qpath),
-            })
-
-        # Phonon DOS calculations.
-        # TODO
-        #if qmesh is not None:
-        #    d.update({
-        #        "nph1l": 1,
-        #        "qph1l": 1,
-        #    })
-        d.update(self.to_abivars())
-
-        from .wrappers import Anaddb
-        anaddb = Anaddb(executable=executable, verbose=verbose)
-        #anaddb.set_input(d)
-        #phband, phdos, events = anaddb.fourier_interpolation()
+#    Subclasses should extend the base method `to_abivars` and provide the method `suggested_kptopt`
+#    that returns the value of kptopt that can be used to sample the Brillouin zone.
+#    """
+#    def __init__(self, qpt):
+#        """
+#        Args:
+#            qpt:
+#                reduced coordinates of the q-point associated to the perturbation.
+#        """
+#        self.qpt = np.reshape(qpt, (-1,3))
+#        self.nqpt = len(self.qpt)
+#
+#    @property
+#    def qpt_is_gamma(self):
+#        """True if the q-point of the perturbation is Gamma."""
+#        return np.all(np.abs(self.qpt) < 1.e-6)
+#
+#    @abc.abstractproperty
+#    def suggested_kptopt(self):
+#        """Returns the suggested value of kptopt to use for this perturbation."""
+#        return 3
+#
+#    def to_abivars(self):
+#        return dict(nqpt=1, qpt=self.qpt)
+#
+#
+#class IFC(AbivarAble):
+#    """
+#    This object defines the set of variables used for the
+#    Fourier interpolation of the interatomic force constants.
+#    """
+#    def __init__(self, ddb_filename, ngqpt, q1shfts=(0.,0.,0.), ifcflag=1, brav=1):
+#        """
+#        For the complete description of the meaning of the variables see anaddb_help.html
+#
+#        Args:
+#            ddb_filename:
+#                Path to the DDB file.
+#            ngqpt:
+#                Monkhorst-Pack divisions.
+#            q1shfts:
+#                Monkhorst-Pack shifts.
+#            ifcflag:
+#                Interatomic force constant flag.
+#            brav:
+#                Bravais Lattice: 1-S.C., 2-F.C., 3-B.C., 4-Hex.
+#        """
+#        self.ddb_filename = os.path.abspath(ddb_filename)
+#        if not os.path.exists(self.ddb_filename):
+#            raise ValueError("%s: no such file" % self.ddb_filename)
+#
+#        self.ifcflag = ifcflag
+#        self.brav = brav
+#        self.ngqpt = ngqpt
+#
+#        self.q1shft = np.reshape(q1shft, (-1,3))
+#        self.nqshft = len(self.q1shft)
+#
+#    def to_abivars(self):
+#        d = dict(
+#            ifcflag=self.ifcflag,
+#            brav=self.brav,
+#            ngqpt="%d %d %d" % tuple(q for q in self.ngqpt),
+#            nqshft=self.nqshft,
+#            )
+#
+#        lines = []
+#        for shift in self.q1shfts:
+#            lines.append("%f %f %f" % tuple(c for c in shift))
+#        d["q1shfts"] = "\n".join(lines)
+#
+#        return d
+#
+#    def fourier_interpol(self, qpath=None, qmesh=None, symdynmat=1, asr=1, chneut=1, dipdip=1,
+#                         executable=None, verbose=0):
+#        """
+#        Fourier interpolation of the IFCs.
+#
+#        Args:
+#            asr:
+#                Acoustic Sum Rule. 1 to impose it asymetrically.
+#            chneut:
+#                Charge neutrality requirement for effective charges.
+#            dipdip:
+#                Dipole-dipole interaction treatment.
+#            symdinmat:
+#                TODO
+#        """
+#        # Build input for anaddb. Variables are stored in the dict d.
+#        d = {
+#            "symdynmat": symdynmat,
+#            "asr"      : asr,
+#            "chneut"   : chneut,
+#            "dipdip"   : dipdip,
+#        }
+#
+#        # Phonon band structure.
+#        if qpath is not None:
+#            qpath = np.reshape(qpath, (-1,3))
+#            d.update({
+#                "nqpath": len(qpath),
+#                "qpath" : "\n".join("%f %f %f" % tuple(q) for q in qpath),
+#            })
+#
+#        # Phonon DOS calculations.
+#        # TODO
+#        #if qmesh is not None:
+#        #    d.update({
+#        #        "nph1l": 1,
+#        #        "qph1l": 1,
+#        #    })
+#        d.update(self.to_abivars())
+#
+#        from .wrappers import Anaddb
+#        anaddb = Anaddb(executable=executable, verbose=verbose)
+#        #anaddb.set_input(d)
+#        #phband, phdos, events = anaddb.fourier_interpolation()
