@@ -15,7 +15,6 @@ import os
 import abc
 import string
 import copy
-import functools
 import getpass
 
 from subprocess import Popen, PIPE
@@ -31,6 +30,7 @@ __all__ = [
     "qadapter_class",
 ]
 
+
 class Command(object):
     """
     From https://gist.github.com/kirpit/1306188
@@ -266,6 +266,32 @@ class AbstractQueueAdapter(object):
     #def set_queue_walltime(self):
     #    """Set the walltime in seconds."""
 
+    #@abc.abstractproperty
+    #def mem_per_cpu(self):
+    #    """The memory per CPU in Megabytes."""
+                                                
+    @abc.abstractmethod
+    def set_mem_per_cpu(self, mem_mb):
+        """Set the memory per CPU in Megabytes"""
+
+    #@property
+    #def tot_mem(self):
+    #    """Total memory required by the job n Megabytes."""
+    #    return self.mem_per_cpu * self.mpi_ncpus
+
+    @abc.abstractmethod
+    def cancel(self, job_id):
+        """
+        Cancel the job. 
+
+        Args:
+            job_id:
+                (in) Job identifier.
+
+        Returns:
+            Exit status.
+        """
+
     def _make_qheader(self, job_name, qout_path, qerr_path):
         """Return a string with the options that are passed to the resource manager."""
         qtemplate = QScriptTemplate(self.QTEMPLATE)
@@ -393,6 +419,12 @@ export MPI_NCPUS=$${MPI_NCPUS}
         """Set the number of CPUs used for MPI."""
         self.qparams["MPI_NCPUS"] = mpi_ncpus
 
+    def set_mem_per_cpu(self, mem_mb):
+        """mem_per_cpu is not available in ShellAdapter."""
+
+    def cancel(self, job_id):
+        return os.system("kill -9 %d" % job_id)
+
     def submit_to_queue(self, script_file):
 
         if not os.path.exists(script_file):
@@ -427,6 +459,7 @@ class SlurmAdapter(AbstractQueueAdapter):
 #SBATCH --job-name=$${job_name}
 #SBATCH	--nodes=$${nodes}
 #SBATCH --mem=$${mem}
+#SBATCH --mem-per-cpu=$${mem_per_cpu}
 #SBATCH --mail-user=$${mail_user}
 #SBATCH --mail-type=$${mail_type}
 #SBATCH --constraint=$${constraint}
@@ -449,6 +482,15 @@ class SlurmAdapter(AbstractQueueAdapter):
         """Set the number of CPUs used for MPI."""
         self.qparams["ntasks"] = mpi_ncpus
 
+    def set_mem_per_cpu(self, mem_mb):
+        """Set the memory per CPU in Megabytes"""
+        self.qparams["mem_per_cpu"] = int(mem_mb)
+        # Remove mem if it's defined.
+        self.qparams.pop("mem", None)
+
+    def cancel(self, job_id):
+        return os.system("scancel %d" % job_id)
+
     def submit_to_queue(self, script_file):
 
         if not os.path.exists(script_file):
@@ -540,6 +582,16 @@ class PbsAdapter(AbstractQueueAdapter):
         ppnode = self.qparams.get("ppn")
         self.qparams["nodes"] = mpi_ncpus // ppnode 
 
+    def set_mem_per_cpu(self, mem_mb):
+        """Set the memory per CPU in Megabytes"""
+        raise NotImplementedError("")
+        #self.qparams["mem_per_cpu"] = mem_mb
+        ## Remove mem if it's defined.
+        #self.qparams.pop("mem", None)
+
+    def cancel(self, job_id):
+        return os.system("qdel %d" % job_id)
+
     def submit_to_queue(self, script_file):
 
         if not os.path.exists(script_file):
