@@ -26,7 +26,7 @@ import CifFile
 import numpy as np
 
 from pymatgen.core.periodic_table import Element, Specie
-from pymatgen.util.io_utils import zopen
+from monty.io import zopen
 from pymatgen.util.coord_utils import in_coord_list_pbc
 from pymatgen.util.string_utils import remove_non_ascii
 from pymatgen.core.lattice import Lattice
