@@ -96,7 +96,7 @@ class QcTask(MSONable):
             self.mol = self.mol.lower()
         self.charge = charge
         self.spin_multiplicity = spin_multiplicity
-        if self.mol != "read":
+        if not (isinstance(self.mol, str) and self.mol == "read"):
             if not isinstance(self.mol, Molecule):
                 raise ValueError("The molecule must be a pymatgen Molecule "
                                  "object or read/None")
@@ -510,7 +510,7 @@ class QcTask(MSONable):
         if self.charge is not None:
             lines.append(" {charge:d}  {multi:d}".format(charge=self
                          .charge, multi=self.spin_multiplicity))
-        if self.mol == "read":
+        if isinstance(self.mol, str) and self.mol == "read":
             lines.append(" read")
         else:
             for site in self.mol.sites:
@@ -608,7 +608,8 @@ class QcTask(MSONable):
     def to_dict(self):
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
-                "molecule": "read" if self.mol == "read" else self.mol.to_dict,
+                "molecule": self.mol if isinstance(self.mol, str)
+                else self.mol.to_dict,
                 "charge": self.charge,
                 "spin_multiplicity": self.spin_multiplicity,
                 "params": self.params}
@@ -631,12 +632,12 @@ class QcTask(MSONable):
             for k in op_keys:
                 optional_params[k] = d["params"][k]
         return QcTask(molecule=mol, charge=d["charge"],
-                       spin_multiplicity=d["spin_multiplicity"],
-                       jobtype=jobtype, title=title,
-                       exchange=exchange, correlation=correlation,
-                       basis_set=basis_set, aux_basis_set=aux_basis_set,
-                       ecp=ecp, rem_params=d["params"]["rem"],
-                       optional_params=optional_params)
+                      spin_multiplicity=d["spin_multiplicity"],
+                      jobtype=jobtype, title=title,
+                      exchange=exchange, correlation=correlation,
+                      basis_set=basis_set, aux_basis_set=aux_basis_set,
+                      ecp=ecp, rem_params=d["params"]["rem"],
+                      optional_params=optional_params)
 
     def write_file(self, filename):
         with zopen(filename, "w") as f:
@@ -682,7 +683,7 @@ class QcTask(MSONable):
                     sorted(list(cls.optional_keywords_list))
                 if section_name not in available_sections:
                     raise ValueError("Unrecognized keyword " + line.strip() +
-                                     "at line " + str(line_num))
+                                     " at line " + str(line_num))
                 if section_name in params:
                     raise ValueError("duplicated keyword " + line.strip() +
                                      "at line " + str(line_num))
@@ -717,12 +718,12 @@ class QcTask(MSONable):
             for k in op_keys:
                 optional_params[k] = params[k]
         return QcTask(molecule=mol, charge=charge,
-                       spin_multiplicity=spin_multiplicity,
-                       jobtype=jobtype, title=title,
-                       exchange=exchange, correlation=correlation,
-                       basis_set=basis_set, aux_basis_set=aux_basis_set,
-                       ecp=ecp, rem_params=params["rem"],
-                       optional_params=optional_params)
+                      spin_multiplicity=spin_multiplicity,
+                      jobtype=jobtype, title=title,
+                      exchange=exchange, correlation=correlation,
+                      basis_set=basis_set, aux_basis_set=aux_basis_set,
+                      ecp=ecp, rem_params=params["rem"],
+                      optional_params=optional_params)
 
     @classmethod
     def _parse_comments(cls, contents):
@@ -1098,7 +1099,8 @@ class QcOutput(object):
             (re.compile("\s+[Nn][Aa][Nn]\s+"), "NAN values"),
             (re.compile("energy\s+=\s*(\*)+"), "Numerical disaster"),
             (re.compile("NewFileMan::OpenFile():\s+nopenfiles=\d+\s+"
-                        "maxopenfiles=\d+s+errno=\d+"), "Open file error")
+                        "maxopenfiles=\d+s+errno=\d+"), "Open file error"),
+            (re.compile("Application \d+ exit codes: 134"), "Exit Code 134")
         )
 
         energies = []
@@ -1270,17 +1272,20 @@ class QcOutput(object):
             else:
                 v *= cls.kcal_per_mol_2_eV
             thermal_corr[k] = v
+
+        solvent_method = "NA"
+        if qctask:
+            if "solvent_method" in qctask.params["rem"]:
+                solvent_method = qctask.params["rem"]["solvent_method"]
+        else:
+            errors.append("No input text")
+
         if len(errors) == 0:
             for text in cls._expected_successful_pattern(qctask):
                 success_pattern = re.compile(text)
                 if not success_pattern.search(output):
                     errors.append("Can't find text to indicate success")
 
-        if "solvent_method" in qctask.params["rem"]:
-            solvent_method = qctask.params["rem"]["solvent_method"]
-        else:
-            solvent_method = "NA"
-
         data = {
             "jobtype": jobtype,
             "energies": energies,
