@@ -31,11 +31,12 @@ from pymatgen.core.physical_constants import BOLTZMANN_CONST
 from pymatgen.core.design_patterns import Enum
 from pymatgen.core.structure import Structure
 from pymatgen.core.periodic_table import Element
-from pymatgen.util.decorators import cached_class
+from monty.design_patterns import cached_class
 from pymatgen.util.string_utils import str_aligned, str_delimited
-from pymatgen.util.io_utils import zopen, clean_lines, zpath
+from pymatgen.util.io_utils import clean_lines, zpath
 from pymatgen.serializers.json_coders import MSONable, PMGJSONDecoder
 import pymatgen
+from monty.io import zopen
 
 
 logger = logging.getLogger(__name__)
@@ -47,6 +48,21 @@ class Poscar(MSONable):
     Please note that this current implementation. Most attributes can be set
     directly.
 
+    Args:
+        structure (Structure):  Structure object.
+        comment (str): Optional comment line for POSCAR. Defaults to unit
+            cell formula of structure. Defaults to None.
+        selective_dynamics (Nx3 array): bool values for selective dynamics,
+            where N is number of sites. Defaults to None.
+        true_names (bool): Set to False is the names in the POSCAR are not
+            well-defined and ambiguous. This situation arises commonly in
+            vasp < 5 where the POSCAR sometimes does not contain element
+            symbols. Defaults to True.
+        velocities (Nx3 array): Velocities for the POSCAR. Typically parsed
+            in MD runs or can be used to initialize velocities.
+        predictor_corrector (Nx3 array): Predictor corrector for the POSCAR.
+            Typically parsed in MD runs.
+
     .. attribute:: structure
 
         Associated Structure.
@@ -83,29 +99,6 @@ class Poscar(MSONable):
 
     def __init__(self, structure, comment=None, selective_dynamics=None,
                  true_names=True, velocities=None, predictor_corrector=None):
-        """
-        Args:
-            structure:
-                Structure object. See pymatgen.core.structure.Structure.
-            comment:
-                Optional comment line for POSCAR. Defaults to unit cell
-                formula of structure. Defaults to None.
-            selective_dynamics:
-                Nx3 2D array of boolean values for selective dynamics, where N
-                is number of sites. Defaults to None.
-            true_names:
-                Set to False is the names in the POSCAR are not well-defined
-                and ambiguous. This situation arises commonly in vasp < 5 where
-                the POSCAR sometimes does not contain element symbols. Defaults
-                to True.
-            velocities:
-                Velocities for the POSCAR. Typically parsed in MD runs or can
-                be used to initialize velocities.
-            predictor_corrector:
-                Velocities for the POSCAR. Typically parsed in MD runs or can
-                be used to initialize velocities.
-        """
-
         if structure.is_ordered:
             self.structure = structure
             self.true_names = true_names
@@ -176,11 +169,9 @@ class Poscar(MSONable):
         require specific elemental properties should work fine.
 
         Args:
-            filename:
-                File name containing Poscar data.
-            check_for_POTCAR:
-                Whether to check if a POTCAR is present in the same directory
-                as the POSCAR. Defaults to True.
+            filename (str): File name containing Poscar data.
+            check_for_POTCAR (bool): Whether to check if a POTCAR is present
+                in the same directory as the POSCAR. Defaults to True.
 
         Returns:
             Poscar object.
@@ -220,11 +211,9 @@ class Poscar(MSONable):
         require specific elemental properties should work fine.
 
         Args:
-            data:
-                string containing Poscar data.
-            default_names:
-                default symbols for the POSCAR file, usually coming from a
-                POTCAR in the same directory.
+            data (str): String containing Poscar data.
+            default_names ([str]): Default symbols for the POSCAR file,
+                usually coming from a POTCAR in the same directory.
 
         Returns:
             Poscar object.
@@ -343,16 +332,15 @@ class Poscar(MSONable):
         symbols are written, which means compatibility is for vasp >= 5.
 
         Args:
-            direct:
-                Whether coordinates are output in direct or cartesian. Defaults
-                to True.
-            vasp4_compatible:
-                Set to True to omit site symbols on 6th line to maintain
-                backward vasp 4.x compatibility. Defaults to False.
-            significant_figures:
-                Number of significant figures to output all quantities.
-                Defaults to 6. Note that positions are output in fixed point,
-                while velocities are output in scientific format.
+            direct (bool): Whether coordinates are output in direct or
+                cartesian. Defaults to True.
+            vasp4_compatible (bool): Set to True to omit site symbols on 6th
+                line to maintain backward vasp 4.x compatibility. Defaults
+                to False.
+            significant_figures (int): No. of significant figures to
+                output all quantities. Defaults to 6. Note that positions are
+                output in fixed point, while velocities are output in
+                scientific format.
 
         Returns:
             String representation of POSCAR.
@@ -445,8 +433,7 @@ class Poscar(MSONable):
         Overwrites imported velocities, if any.
 
         Args:
-            temperature:
-                Temperature in Kelvin.
+            temperature (float): Temperature in Kelvin.
         """
         # mean 0 variance 1
         velocities = np.random.randn(len(self.structure), 3)
@@ -490,8 +477,7 @@ class Incar(dict):
         Creates an Incar object.
 
         Args:
-            params:
-                A set of input parameters as a dictionary.
+            params (dict): A set of input parameters as a dictionary.
         """
         super(Incar, self).__init__()
         if params:
@@ -526,11 +512,10 @@ class Incar(dict):
         pretty printing.
 
         Args:
-            sort_keys:
-                Set to True to sort the INCAR parameters alphabetically.
-                Defaults to False.
-            pretty:
-                Set to True for pretty aligned output. Defaults to False.
+            sort_keys (bool): Set to True to sort the INCAR parameters
+                alphabetically. Defaults to False.
+            pretty (bool): Set to True for pretty aligned output. Defaults
+                to False.
         """
         keys = self.keys()
         if sort_keys:
@@ -560,8 +545,7 @@ class Incar(dict):
         Write Incar to a file.
 
         Args:
-            filename:
-                filename to write to.
+            filename (str): filename to write to.
         """
         with open(filename, "w") as f:
             f.write(self.__str__() + "\n")
@@ -572,7 +556,7 @@ class Incar(dict):
         Reads an Incar object from a file.
 
         Args:
-            filename - Filename for file
+            filename (str): Filename for file
 
         Returns:
             Incar object
@@ -596,10 +580,8 @@ class Incar(dict):
         integers, floats, lists, etc.
 
         Args:
-            key:
-                INCAR parameter key
-            val:
-                Actual value of INCAR parameter.
+            key: INCAR parameter key
+            val: Actual value of INCAR parameter.
         """
         list_keys = ("LDAUU", "LDAUL", "LDAUJ", "LDAUTYPE", "MAGMOM")
         bool_keys = ("LDAU", "LWAVE", "LSCALU", "LCHARG", "LPLANE", "LHFCALC")
@@ -673,8 +655,7 @@ class Incar(dict):
         two runs were done using the same parameters.
 
         Args:
-            other:
-                The other Incar object to compare to.
+            other (Incar): The other Incar object to compare to.
 
         Returns:
             Dict of the following format:
@@ -734,40 +715,30 @@ class Kpoints(MSONable):
         is recommended that you use those.
 
         Args:
-            comment:
-                String comment for Kpoints
-            num_kpts:
-                Following VASP method of defining the KPOINTS file, this
+            comment (str): String comment for Kpoints
+            num_kpts: Following VASP method of defining the KPOINTS file, this
                 parameter is the number of kpoints specified. If set to 0
                 (or negative), VASP automatically generates the KPOINTS.
-            style:
-                Style for generating KPOINTS.  Use one of the
+            style: Style for generating KPOINTS.  Use one of the
                 Kpoints.supported_modes enum types.
-            kpts:
-                2D array of kpoints.  Even when only a single specification is
-                required, e.g. in the automatic scheme, the kpts should still
-                be specified as a 2D array. e.g., [[20]] or [[2,2,2]].
-            kpts_shift:
-                Shift for Kpoints.
-            kpts_weights:
-                Optional weights for kpoints.  Weights should be integers. For
-                explicit kpoints.
-            coord_type:
-                In line-mode, this variable specifies whether the Kpoints were
-                given in Cartesian or Reciprocal coordinates.
-            labels:
-                In line-mode, this should provide a list of labels for each
-                kpt. It is optional in explicit kpoint mode as comments for
+            kpts (2D array): 2D array of kpoints.  Even when only a single
+                specification is required, e.g. in the automatic scheme,
+                the kpts should still be specified as a 2D array. e.g.,
+                [[20]] or [[2,2,2]].
+            kpts_shift (3x1 array): Shift for Kpoints.
+            kpts_weights: Optional weights for kpoints.  Weights should be
+                integers. For explicit kpoints.
+            coord_type: In line-mode, this variable specifies whether the
+                Kpoints were given in Cartesian or Reciprocal coordinates.
+            labels: In line-mode, this should provide a list of labels for
+                each kpt. It is optional in explicit kpoint mode as comments for
                 k-points.
-            tet_number:
-                For explicit kpoints, specifies the number of tetrahedrons for
-                the tetrahedron method.
-            tet_weight:
-                For explicit kpoints, specifies the weight for each tetrahedron
-                for the tetrahedron method.
-            tet_connections:
-                For explicit kpoints, specifies the connections of the
+            tet_number: For explicit kpoints, specifies the number of
                 tetrahedrons for the tetrahedron method.
+            tet_weight: For explicit kpoints, specifies the weight for each
+                tetrahedron for the tetrahedron method.
+            tet_connections: For explicit kpoints, specifies the connections
+                of the tetrahedrons for the tetrahedron method.
                 Format is a list of tuples, [ (sym_weight, [tet_vertices]),
                 ...]
 
@@ -805,9 +776,8 @@ class Kpoints(MSONable):
         VASP manual.
 
         Args:
-            subdivisions:
-                 Parameter determining number of subdivisions along each
-                 reciprocal lattice vector.
+            subdivisions: Parameter determining number of subdivisions along
+                each reciprocal lattice vector.
 
         Returns:
             Kpoints object
@@ -823,11 +793,9 @@ class Kpoints(MSONable):
         grid.
 
         Args:
-            kpts:
-                Subdivisions N_1, N_2 and N_3 along reciprocal lattice vectors.
-                Defaults to (1,1,1)
-            shift:
-                Shift to be applied to the kpoints. Defaults to (0,0,0).
+            kpts: Subdivisions N_1, N_2 and N_3 along reciprocal lattice
+                vectors. Defaults to (1,1,1)
+            shift: Shift to be applied to the kpoints. Defaults to (0,0,0).
 
         Returns:
             Kpoints object
@@ -843,11 +811,9 @@ class Kpoints(MSONable):
         grid.
 
         Args:
-            kpts:
-                Subdivisions N_1, N_2 and N_3 along reciprocal lattice vectors.
-                Defaults to (2,2,2)
-            shift:
-                Shift to be applied to the kpoints. Defaults to (0,0,0).
+            kpts: Subdivisions N_1, N_2 and N_3 along reciprocal lattice
+                vectors. Defaults to (2,2,2)
+            shift: Shift to be applied to the kpoints. Defaults to (0,0,0).
 
         Returns:
             Kpoints object
@@ -868,10 +834,11 @@ class Kpoints(MSONable):
             reciprocal lattice vector proportional to its length.
 
         Args:
-            structure:
-                Input structure
-            kppa:
-                Grid density
+            structure (Structure): Input structure
+            kppa (int): Grid density
+
+        Returns:
+            Kpoints
         """
 
         latt = structure.lattice
@@ -918,8 +885,7 @@ class Kpoints(MSONable):
         Reads a Kpoints object from a KPOINTS file.
 
         Args:
-            filename:
-                filename to read from.
+            filename (str): filename to read from.
 
         Returns:
             Kpoints object
@@ -1020,8 +986,7 @@ class Kpoints(MSONable):
         Write Kpoints to a file.
 
         Args:
-            filename:
-                filename to write to.
+            filename (str): Filename to write to.
         """
         with open(filename, "w") as f:
             f.write(self.__str__() + "\n")
@@ -1102,6 +1067,10 @@ class PotcarSingle(object):
     the POTCAR contains the complete untouched data in "data" as a string and
     a dict of keywords.
 
+    Args:
+        data:
+            Complete and single potcar file as a string.
+
     .. attribute:: data
 
         POTCAR data as a string.
@@ -1116,11 +1085,6 @@ class PotcarSingle(object):
                       "PW91": "POT_GGA_PAW_PW91", "LDA_US": "POT_LDA_US"}
 
     def __init__(self, data):
-        """
-        Args:
-            data:
-                Complete and single potcar file as a string.
-        """
         self.data = data  # raw POTCAR as a string
 
         # AJ (5/18/2012) - only search on relevant portion of POTCAR, should
@@ -1209,23 +1173,19 @@ class Potcar(list):
     """
     Object for reading and writing POTCAR files for calculations. Consists of a
     list of PotcarSingle.
+
+    Args:
+        symbols ([str]): Element symbols for POTCAR. This should correspond
+            to the symbols used by VASP. E.g., "Mg", "Fe_pv", etc.
+        functional (str): Functional used.
+        sym_potcar_map (dict): Allows a user to specify a specific element
+            symbol to raw POTCAR mapping.
     """
 
     DEFAULT_FUNCTIONAL = "PBE"
 
     def __init__(self, symbols=None, functional=DEFAULT_FUNCTIONAL,
                  sym_potcar_map=None):
-        """
-        Args:
-            symbols:
-                Element symbols for POTCAR. This should correspond to the
-                symbols used by VASP. E.g., "Mg", "Fe_pv", etc.
-            functional:
-                Functional used.
-            sym_potcar_map:
-                Allows a user to specify a specific element symbol to raw
-                POTCAR mapping.
-        """
         super(Potcar, self).__init__()
         self.functional = functional
         if symbols is not None:
@@ -1273,8 +1233,7 @@ class Potcar(list):
         Write Potcar to a file.
 
         Args:
-            filename:
-                filename to write to.
+            filename (str): filename to write to.
         """
         with open(filename, "w") as f:
             f.write(self.__str__() + "\n")
@@ -1294,14 +1253,11 @@ class Potcar(list):
         VASP_PSP_DIR or in a pymatgen.cfg or specified explicitly in a map.
 
         Args:
-            symbols:
-                A list of element symbols
-            functional:
-                (optional) the functional to use from the config file
-            sym_potcar_map:
-                (optional) a map of symbol:raw POTCAR string. If sym_potcar_map
-                is specified, POTCARs will be generated from the given map data
-                rather than the config file location.
+            symbols ([str]): A list of element symbols
+            functional (str): The functional to use from the config file
+            sym_potcar_map (dict): A map of symbol:raw POTCAR string. If
+                sym_potcar_map is specified, POTCARs will be generated from
+                the given map data rather than the config file location.
         """
         del self[:]
         if sym_potcar_map:
@@ -1316,25 +1272,19 @@ class Potcar(list):
 class VaspInput(dict, MSONable):
     """
     Class to contain a set of vasp input objects corresponding to a run.
+
+    Args:
+        incar: Incar object.
+        kpoints: Kpoints object.
+        poscar: Poscar object.
+        potcar: Potcar object.
+        optional_files: Other input files supplied as a dict of {
+            filename: object}. The object should follow standard pymatgen
+            conventions in implementing a to_dict and from_dict method.
     """
 
     def __init__(self, incar, kpoints, poscar, potcar, optional_files=None,
                  **kwargs):
-        """
-        Args:
-            incar:
-                Incar object.
-            kpoints:
-                Kpoints object.
-            poscar:
-                Poscar object.
-            potcar:
-                Potcar object.
-            optional_files:
-                Other input files supplied as a dict of {filename: object}.
-                The object should follow standard pymatgen conventions in
-                implementing a to_dict and from_dict method.
-        """
         super(VaspInput, self).__init__(**kwargs)
         self.update({'INCAR': incar,
                      'KPOINTS': kpoints,
@@ -1374,10 +1324,10 @@ class VaspInput(dict, MSONable):
         Write VASP input to a directory.
 
         Args:
-            output_dir:
-                Directory to write to. Defaults to current directory (".").
-            make_dir_if_not_present:
-                Create the directory if not present. Defaults to True.
+            output_dir (str): Directory to write to. Defaults to current
+                directory (".").
+            make_dir_if_not_present (bool): Create the directory if not
+                present. Defaults to True.
         """
         if make_dir_if_not_present and not os.path.exists(output_dir):
             os.makedirs(output_dir)
@@ -1393,11 +1343,10 @@ class VaspInput(dict, MSONable):
         optional_filenames is specified.
 
         Args:
-            input_dir:
-                Directory to read VASP input from.
-            optional_files:
-                Optional files to read in as well as a dict of {filename:
-                Object type}. Object type must have a static method from_file.
+            input_dir (str): Directory to read VASP input from.
+            optional_files (dict): Optional files to read in as well as a
+                dict of {filename: Object type}. Object type must have a
+                static method from_file.
         """
         sub_d = {}
         for fname, ftype in [("INCAR", Incar), ("KPOINTS", Kpoints),
