@@ -17,7 +17,7 @@ import numpy as np
 from fractions import gcd, Fraction
 
 from pymatgen.core.structure import Specie, Composition
-from pymatgen.core.periodic_table import smart_element_or_specie
+from pymatgen.core.periodic_table import get_el_sp
 from pymatgen.transformations.transformation_abc import AbstractTransformation
 from pymatgen.transformations.standard_transformations import \
     SubstitutionTransformation, OrderDisorderedStructureTransformation
@@ -38,19 +38,17 @@ class ChargeBalanceTransformation(AbstractTransformation):
     """
     This is a transformation that disorders a structure to make it charge
     balanced, given an oxidation state-decorated structure.
-    """
 
+    Args:
+        charge_balance_sp: specie to add or remove. Currently only removal
+            is supported
+    """
     def __init__(self, charge_balance_sp):
-        """
-        Args:
-            charge_balance_sp
-                specie to add or remove. Currently only removal is supported
-        """
         self._charge_balance_sp = str(charge_balance_sp)
 
     def apply_transformation(self, structure):
         charge = structure.charge
-        specie = smart_element_or_specie(self._charge_balance_sp)
+        specie = get_el_sp(self._charge_balance_sp)
         num_to_remove = charge / specie.oxi_state
         num_in_structure = structure.composition[specie]
         removal_fraction = num_to_remove / num_in_structure
@@ -91,15 +89,13 @@ class SuperTransformation(AbstractTransformation):
     from a list of transformations and returns one structure for each
     transformation. The primary use for this class is extending a transmuter
     object.
+
+    Args:
+        transformations: List of transformations to apply to a structure.
+            One transformation is applied to each output structure.
     """
 
     def __init__(self, transformations):
-        """
-        Args:
-            transformations:
-                list of transformations to apply to a structure. One
-                transformation is applied to each output structure.
-        """
         self._transformations = transformations
 
     def apply_transformation(self, structure, return_ranked_list=False):
@@ -108,9 +104,9 @@ class SuperTransformation(AbstractTransformation):
                              " output. Must use return_ranked_list")
         structures = []
         for t in self._transformations:
-            structures.append({"transformation": t,
-                               "structure": t.apply_transformation(structure)})
-
+            structures.append(
+                {"transformation": t,
+                 "structure": t.apply_transformation(structure)})
         return structures
 
     def __str__(self):
@@ -156,12 +152,9 @@ class MultipleSubstitutionTransformation(object):
         Performs multiple fractional substitutions on a transmuter.
 
         Args:
-            sp_to_replace
-                species to be replaced
-            r_fraction
-                fraction of that specie to replace
-            substitution_dict
-                dictionary of the format
+            sp_to_replace: species to be replaced
+            r_fraction: fraction of that specie to replace
+            substitution_dict: dictionary of the format
                 {2: ["Mg", "Ti", "V", "As", "Cr", "Ta", "N", "Nb"],
                 3: ["Ru", "Fe", "Co", "Ce", "As", "Cr", "Ta", "N", "Nb"],
                 4: ["Ru", "V", "Cr", "Ta", "N", "Nb"],
@@ -169,8 +162,7 @@ class MultipleSubstitutionTransformation(object):
                 }
                 The number is the charge used for each of the list of elements
                 (an element can be present in multiple lists)
-            charge_balance_species:
-                If specified, will balance the charge on the structure using
+            charge_balance_species: If specified, will balance the charge on the structure using
                 that specie.
         """
         self._sp_to_replace = sp_to_replace
@@ -248,30 +240,30 @@ class EnumerateStructureTransformation(AbstractTransformation):
     Order a disordered structure using enumlib. For complete orderings, this
     generally produces fewer structures that the OrderDisorderedStructure
     transformation, and at a much faster speed.
+
+    Args:
+        min_cell_size:
+            The minimum cell size wanted. Must be an int. Defaults to 1.
+        max_cell_size:
+            The maximum cell size wanted. Must be an int. Defaults to 1.
+        symm_prec:
+            Tolerance to use for symmetry.
+        refine_structure:
+            This parameter has the same meaning as in enumlib_caller.
+            If you are starting from a structure that has been relaxed via
+            some electronic structure code, it is usually much better to
+            start with symmetry determination and then obtain a refined
+            structure. The refined structure have cell parameters and
+            atomic positions shifted to the expected symmetry positions,
+            which makes it much less sensitive precision issues in enumlib.
+            If you are already starting from an experimental cif, refinment
+            should have already been done and it is not necessary. Defaults
+            to False.
     """
 
     def __init__(self, min_cell_size=1, max_cell_size=1, symm_prec=0.1,
                  refine_structure=False):
-        """
-        Args:
-            min_cell_size:
-                The minimum cell size wanted. Must be an int. Defaults to 1.
-            max_cell_size:
-                The maximum cell size wanted. Must be an int. Defaults to 1.
-            symm_prec:
-                Tolerance to use for symmetry.
-            refine_structure:
-                This parameter has the same meaning as in enumlib_caller.
-                If you are starting from a structure that has been relaxed via
-                some electronic structure code, it is usually much better to
-                start with symmetry determination and then obtain a refined
-                structure. The refined structure have cell parameters and
-                atomic positions shifted to the expected symmetry positions,
-                which makes it much less sensitive precision issues in enumlib.
-                If you are already starting from an experimental cif, refinment
-                should have already been done and it is not necessary. Defaults
-                to False.
-        """
+
         self.symm_prec = symm_prec
         self.min_cell_size = min_cell_size
         self.max_cell_size = max_cell_size
@@ -283,10 +275,8 @@ class EnumerateStructureTransformation(AbstractTransformation):
         structures.
 
         Args:
-            structure:
-                Structure to order.
-            return_ranked_list:
-                Boolean stating whether or not multiple structures are
+            structure: Structure to order.
+            return_ranked_list (bool): Whether or not multiple structures are
                 returned. If return_ranked_list is a number, that number of
                 structures is returned.
 
@@ -388,15 +378,13 @@ class SubstitutionPredictorTransformation(AbstractTransformation):
     """
     This transformation takes a structure and uses the structure
     prediction module to find likely site substitutions.
+
+    Args:
+        threshold: Threshold for substitution.
+        **kwargs: Args for SubstitutionProbability class lambda_table, alpha
     """
 
     def __init__(self, threshold=1e-2, **kwargs):
-        """
-        Args:
-            kwargs:
-                args for SubstitutionProbability class
-                lambda_table, alpha
-        """
         self._kwargs = kwargs
         self._threshold = threshold
         self._substitutor = SubstitutionPredictor(threshold=threshold,
@@ -450,25 +438,24 @@ class MagOrderingTransformation(AbstractTransformation):
     """
     This transformation takes a structure and returns a list of magnetic
     orderings. Currently only works for ordered structures.
+
+    Args:
+        mag_elements_spin:
+            A mapping of elements/species to magnetically order to spin
+            magnitudes. E.g., {"Fe3+": 5, "Mn3+": 4}
+        order_parameter:
+            degree of magnetization. 0.5 corresponds to
+            antiferromagnetic order
+        energy_model:
+            Energy model used to rank the structures. Some models are
+            provided in :mod:`pymatgen.analysis.energy_models`.
+        **kwargs:
+            Same keyword args as :class:`EnumerateStructureTransformation`,
+            i.e., min_cell_size, etc.
     """
 
     def __init__(self, mag_species_spin, order_parameter=0.5,
                  energy_model=SymmetryModel(), **kwargs):
-        """
-        Args:
-            mag_elements_spin:
-                A mapping of elements/species to magnetically order to spin
-                magnitudes. E.g., {"Fe3+": 5, "Mn3+": 4}
-            order_parameter:
-                degree of magnetization. 0.5 corresponds to
-                antiferromagnetic order
-            energy_model:
-                Energy model used to rank the structures. Some models are
-                provided in :mod:`pymatgen.analysis.energy_models`.
-            **kwargs:
-                Same keyword args as :class:`EnumerateStructureTransformation`,
-                i.e., min_cell_size, etc.
-        """
         self.mag_species_spin = mag_species_spin
         if order_parameter > 1 or order_parameter < 0:
             raise ValueError('Order Parameter must lie between 0 and 1')
@@ -507,7 +494,7 @@ class MagOrderingTransformation(AbstractTransformation):
         #Make a mutable structure first
         mods = Structure.from_sites(structure)
         for sp, spin in self.mag_species_spin.items():
-            sp = smart_element_or_specie(sp)
+            sp = get_el_sp(sp)
             oxi_state = getattr(sp, "oxi_state", 0)
             up = Specie(sp.symbol, oxi_state, {"spin": abs(spin)})
             down = Specie(sp.symbol, oxi_state, {"spin": -abs(spin)})
